@@ -30,3 +30,7 @@ def release_logid():
         return False
     del _thread_logid_map[current_thread_id]
     return True
+
+def set_logid(log_id):
+    global _thread_logid_map
+    _thread_logid_map[_get_current_thread_id()] = log_id
